@@ -10,7 +10,7 @@ pub struct NetworkFormatter {
 impl NetworkFormatter {
     pub fn new() -> Self {
         Self {
-            logical_address: String::from("N/A"),
+            logical_address: String::new(),
             rx_bytes: 0,
             tx_bytes: 0,
         }
@@ -20,6 +20,10 @@ impl NetworkFormatter {
         self.logical_address = addr;
     }
 
+    pub fn get_logical_address(&self) -> &str {
+        &self.logical_address
+    }
+
     pub fn set_rx_bytes(&mut self, bytes: usize) {
         self.rx_bytes = bytes;
     }
@@ -46,9 +50,30 @@ impl fmt::Display for NetworkFormatter {
         write!(
             f,
             "Local IP: {}\nData: {} 🠗 / {} 🠕",
-            self.logical_address,
+            self.get_logical_address(),
             self.get_rx_bytes(),
             self.get_tx_bytes(),
         )
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn display_network() {
+        let mut fmt = NetworkFormatter::new();
+
+        fmt.set_logical_address("127.0.0.1".to_owned());
+        assert_eq!(fmt.to_string(), "Local IP: 127.0.0.1".to_owned());
+
+        fmt.set_logical_address("192.168.1.1".to_owned());
+        fmt.set_rx_bytes(717000);
+        fmt.set_tx_bytes(717000);
+        assert_eq!(
+            fmt.to_string(),
+            "Local IP: 192.168.1.1\nData: 700.0 KB 🠗 / 700.0 KB 🠕".to_owned()
+        );
+    }
+}
