@@ -46,3 +46,22 @@ impl fmt::Display for UptimeFormatter {
         write!(f, "{}", compiled.join(", "))
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn from_usize_to_uptime() {
+        let fmt = UptimeFormatter::from(7500);
+        assert_eq!(fmt.days, 0);
+        assert_eq!(fmt.hours, 2);
+        assert_eq!(fmt.minutes, 5);
+    }
+
+    #[test]
+    fn display_uptime() {
+        let fmt = UptimeFormatter::from(7260);
+        assert_eq!(fmt.to_string(), "2 hours, 1 minute".to_owned());
+    }
+}
