@@ -16,8 +16,9 @@ use crate::fmt::memory::MemoryFormatter;
 use crate::fmt::network::NetworkFormatter;
 use crate::fmt::uptime::UptimeFormatter;
 use crate::helpers;
+use crate::Icon;
 
-use chrono::{Datelike, Timelike, Utc};
+use chrono::{Datelike, Timelike};
 
 pub fn uptime() -> Result<String, ReadoutError> {
     let readout = GeneralReadout::new();
@@ -48,12 +49,13 @@ pub fn memory() -> Result<String, ReadoutError> {
     Ok(fmt.to_string())
 }
 
-pub fn battery() -> Result<String, ReadoutError> {
+pub fn battery(icon: &mut Icon) -> Result<String, ReadoutError> {
     let mut fmt = BatteryFormatter::new();
     let readout = BatteryReadout::new();
 
     fmt.set_percentage(readout.percentage()?);
     fmt.set_state(readout.status()?);
+    fmt.set_icon(icon);
 
     Ok(fmt.to_string())
 }
@@ -67,24 +69,26 @@ pub fn backlight() -> Result<String, ReadoutError> {
     Ok(fmt.to_string())
 }
 
-pub fn date() -> Result<String, ReadoutError> {
+pub fn date(railway: bool, icon: &mut Icon) -> Result<String, ReadoutError> {
     let mut fmt = DateFormatter::new();
+    if let Some(readout) = helpers::utc_from_timezone() {
+        fmt.set_weekday(readout.weekday());
+        fmt.set_month(readout.month());
+        fmt.set_day(readout.day());
+        fmt.set_minute(readout.minute());
 
-    if let Some(timezone) = helpers::get_timezone() {
-        let timezone = chrono_tz::TZ_VARIANTS
-            .iter()
-            .find(|&v| *v.to_string() == timezone);
+        if railway {
+            fmt.set_hour(readout.hour());
+            fmt.enable_railway();
+        } else {
+            let h = readout.hour12();
+            fmt.set_meridiem(h.0);
+            fmt.set_hour(h.1);
+        };
 
-        if let Some(tz) = timezone {
-            let readout = Utc::now().with_timezone(tz);
-            fmt.set_day(readout.day());
-            fmt.set_hour(readout.hour12());
-            fmt.set_month(readout.month());
-            fmt.set_weekday(readout.weekday());
-            fmt.set_minute(readout.minute());
+        fmt.set_icon(icon);
 
-            return Ok(fmt.to_string());
-        }
+        return Ok(fmt.to_string());
     }
 
     Err(ReadoutError::Other(
